@@ -22,10 +22,6 @@ from metamoth.enums import (
 )
 
 
-def _rounded_div(a, b):  # pylint: disable=invalid-name
-    return ((a) + (b / 2)) / (b)
-
-
 def _get_datetime_1_0(time: datetime.datetime) -> str:
     return (
         f"{time.hour:02d}:{time.minute:02d}:{time.second:02d} "
@@ -55,7 +51,6 @@ def generate_comment_v1_0(
     config: Config1_0,
 ):
     """Generate a comment in the format of the firmware version 1.0."""
-
     time_str = _get_datetime_1_0(time)
     battery_str = _get_battery_state_1_0(battery_state)
     gain_str = _get_gain_setting_1_0(config.gain)
@@ -175,13 +170,15 @@ def _get_timezone_1_2_2(hours: int, minutes: int) -> str:
         hours_str = f"+{hours:d}"
     elif hours < 0:
         hours_str = f"{hours:d}"
+    elif minutes != 0:
+        hours_str = "+0"
     else:
         hours_str = ""
 
     if minutes > 0:
-        minutes_str = f":{minutes:2d}"
+        minutes_str = f":{minutes:02d}"
     elif minutes < 0:
-        minutes_str = f":{-minutes:2d}"
+        minutes_str = f":{-minutes:02d}"
     else:
         minutes_str = ""
 
@@ -199,7 +196,6 @@ def generate_comment_v1_2_2(
 
     Also used for firmware version 1.3.0.
     """
-
     time_str = _get_datetime_1_0(time)
     battery_str = _get_battery_state_1_2_1(battery_state)
     gain_str = _get_gain_setting_1_0(config.gain)
@@ -218,11 +214,15 @@ def generate_comment_v1_2_2(
 def _get_frequency_filter_1_4_0(
     lower_filter_freq: int, higher_filter_freq: int
 ) -> str:
+    """Get the frequency filter string.
+
+    We assume that the filter frequencies are in units of Hz.
+    """
     if lower_filter_freq == 0 and higher_filter_freq == 0:
         return ""
 
-    low_freq = lower_filter_freq / 10
-    high_freq = higher_filter_freq / 10
+    low_freq = lower_filter_freq / 1000
+    high_freq = higher_filter_freq / 1000
 
     if lower_filter_freq > 0 and higher_filter_freq > 0:
         return (
@@ -230,7 +230,7 @@ def _get_frequency_filter_1_4_0(
             f"{low_freq:01.01f}kHz and {high_freq:01.01f}kHz."
         )
 
-    if lower_filter_freq > 0:
+    if higher_filter_freq > 0:
         return (
             " Low-pass filter applied with cut-off frequency of "
             f"{high_freq:01.01f}kHz."
@@ -242,10 +242,8 @@ def _get_frequency_filter_1_4_0(
     )
 
 
-def _get_temperature_1_4_0(temperature: int) -> str:
-    sign = "-" if temperature < 0 else ""
-    temp_in_decidegrees = _rounded_div(abs(temperature), 100)
-    return f"{sign}{temp_in_decidegrees / 10:1.1f}"
+def _get_temperature_1_4_0(temperature: float) -> str:
+    return f"temperature was {temperature:2.1f}C"
 
 
 def _get_battery_state_1_4_0(battery_state: ExtendedBatteryState) -> str:
@@ -255,7 +253,7 @@ def _get_battery_state_1_4_0(battery_state: ExtendedBatteryState) -> str:
     if battery_state == ExtendedBatteryState.AM_EXT_BAT_FULL:
         return "battery state was greater than 4.9V"
 
-    voltage = (battery_state.value + 35) / 10
+    voltage = battery_state.volts
     return f"battery state was {voltage:01.01f}V"
 
 
@@ -273,10 +271,12 @@ def _get_timezone_1_4_0(hours: int, minutes: int) -> str:
 
     minutes_str = ""
     if minutes < 0:
-        hours_str = f"-{hours:d}"
+        if hours == 0:
+            hours_str = "-0"
         minutes_str = f":{-minutes:d}"
     elif minutes > 0:
-        hours_str = f"+{hours:02d}"
+        if hours == 0:
+            hours_str = "+0"
         minutes_str = f":{minutes:02d}"
 
     return f"(UTC{hours_str}{minutes_str})"
@@ -293,12 +293,15 @@ def _get_recording_state_1_4_0(recording_state: RecordingState) -> str:
     if recording_state == RecordingState.RECORDING_OKAY:
         return ""
 
-    cause = "change of switch position"
+    template = " Recording cancelled before completion due to {cause}."
 
     if recording_state == RecordingState.SUPPLY_VOLTAGE_LOW:
-        cause = "low voltage"
+        return template.format(cause="low voltage")
 
-    return f" Recording cancelled before completion due to {cause}."
+    if recording_state == RecordingState.SWITCH_CHANGED:
+        return template.format(cause="change of switch position")
+
+    return ""
 
 
 def generate_comment_v1_4_0(
@@ -307,13 +310,12 @@ def generate_comment_v1_4_0(
     extended_battery_state: ExtendedBatteryState,
     config: Config1_4_0,
     recording_state: RecordingState,
-    temperature: int,
+    temperature: float,
 ):
     """Generate a comment in the format of the firmware version 1.4.0.
 
     Also valid for version 1.4.1.
     """
-
     time_str = _get_datetime_1_0(time)
     battery_str = _get_battery_state_1_4_0(extended_battery_state)
     gain_str = _get_gain_setting_1_4_0(config.gain)
@@ -360,13 +362,12 @@ def generate_comment_v1_4_2(
     extended_battery_state: ExtendedBatteryState,
     config: Config1_4_0,
     recording_state: RecordingState,
-    temperature: int,
+    temperature: float,
 ):
     """Generate a comment in the format of the firmware version 1.4.2.
 
     Also valid for versions 1.4.3 and 1.4.4.
     """
-
     time_str = _get_datetime_1_0(time)
     battery_str = _get_battery_state_1_4_0(extended_battery_state)
     gain_str = _get_gain_setting_1_4_0(config.gain)
@@ -430,7 +431,7 @@ def generate_comment_v1_5_0(
     extended_battery_state: ExtendedBatteryState,
     config: Config1_5_0,
     recording_state: RecordingState,
-    temperature: int,
+    temperature: float,
     deployment_id: Optional[int],
     external_microphone: bool,
 ):
@@ -555,7 +556,7 @@ def generate_comment_v1_6_0(
     extended_battery_state: ExtendedBatteryState,
     config: Config1_6_0,
     recording_state: RecordingState,
-    temperature: int,
+    temperature: float,
     deployment_id: Optional[int],
     external_microphone: bool,
 ):
@@ -627,7 +628,7 @@ def generate_comment_v1_7_0(
     extended_battery_state: ExtendedBatteryState,
     config: Config1_7_0,
     recording_state: RecordingState,
-    temperature: int,
+    temperature: float,
     deployment_id: Optional[int],
     external_microphone: bool,
 ):
@@ -697,7 +698,7 @@ def generate_comment_v1_8_0(
     extended_battery_state: ExtendedBatteryState,
     config: Config1_8_0,
     recording_state: RecordingState,
-    temperature: int,
+    temperature: float,
     deployment_id: Optional[int],
     external_microphone: bool,
 ):
